@@ -5,7 +5,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2001-2010 Alvaro Lopez Ortega
+# Copyright (C) 2001-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -60,3 +60,17 @@ def Hide (id):
 
 def GotoURL (url):
     return "window.location = '%s';" %(url)
+
+def ReloadURL():
+    return "window.location.reload();"
+
+def OpenWindow (url):
+    return "window.open ('%s');" %(url)
+
+def get_Hashtag():
+    return "window.location.hash"
+
+def set_Hashtag(tag):
+    if tag[0] in ('"', "'"):
+        return "window.location.hash = %s;" %(tag)
+    return "window.location.hash = '%s';" %(tag)
