@@ -5,7 +5,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2010 Alvaro Lopez Ortega
+# Copyright (C) 2010-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -60,7 +60,7 @@ class Paginator_Footer (Box):
         # Render it
         if page_num != 0:
             url = '%s/%d' %(refreshable.url, page_num-1)
-            link = Link ('#', RawHTML (_("Previous")), {'class': 'paginator-footer-prev'})
+            link = Link (None, RawHTML (_("Previous")), {'class': 'paginator-footer-prev'})
             link.bind ('click', refreshable.JS_to_refresh(url=url))
             self += link
 
@@ -70,7 +70,7 @@ class Paginator_Footer (Box):
                 indexes += RawHTML ("%d"%(p+1))
             else:
                 url = '%s/%d' %(refreshable.url, p)
-                link = Link('#', RawHTML ("%d"%(p+1)), {'class': 'paginator-footer-page'})
+                link = Link (None, RawHTML ("%d"%(p+1)), {'class': 'paginator-footer-page'})
                 link.bind ('click', refreshable.JS_to_refresh(url=url))
                 indexes += link
 
@@ -81,7 +81,7 @@ class Paginator_Footer (Box):
 
         if page_num < total_pages-1:
             url = '%s/%d' %(refreshable.url, page_num+1)
-            link = Link ('#', RawHTML (_("Next")), {'class': 'paginator-footer-next'})
+            link = Link (None, RawHTML (_("Next")), {'class': 'paginator-footer-next'})
             link.bind ('click', refreshable.JS_to_refresh(url=url))
             self += link
 
