@@ -82,8 +82,8 @@ NOTE_KEEPALIVE_RS = N_('Maximum number of HTTP requests that can be served by ea
 NOTE_CHUNKED      = N_('Allows the server to use Chunked encoding to try to keep Keep-Alive enabled.')
 NOTE_IO_ENABLED   = N_('Activate or deactivate the I/O cache globally.')
 NOTE_IO_SIZE      = N_('Number of pages that the cache should handle.')
-NOTE_IO_MIN_SIZE  = N_('Files under this size will not be cached.')
-NOTE_IO_MAX_SIZE  = N_('Files over this size will not be cached.')
+NOTE_IO_MIN_SIZE  = N_('Files under this size (in bytes) will not be cached.')
+NOTE_IO_MAX_SIZE  = N_('Files over this size (in bytes) will not be cached.')
 NOTE_IO_LAST_STAT = N_('How long (in seconds) the file information should last cached without refreshing it.')
 NOTE_IO_LAST_MMAP = N_('How long (in seconds) the file content should last cached.')
 NOTE_DH512        = N_('Path to a Diffie Hellman (DH) parameters PEM file: 512 bits.')
