@@ -25,8 +25,11 @@
 import re
 import copy
 import CTK
+
+from util import *
 from consts import *
 
+
 DEFAULT_RULE_WARNING = N_('The default match ought not to be changed.')
 
 URL_APPLY_LOGIC = "/rule/logic/apply"
@@ -105,8 +108,8 @@ class RuleButtons (CTK.Box):
 
 class Rule (CTK.Box):
     def __init__ (self, key, depth=0):
-        assert type(key) == str
-        assert type(depth) == int
+        assert type(key) == str, type(key)
+        assert type(depth) == int, type(depth)
 
         CTK.Box.__init__ (self, {'class': 'rule'})
         self.key   = key
@@ -147,9 +150,9 @@ class Rule (CTK.Box):
         vsrv_num = self.key.split('!')[1]
 
         if not CTK.cfg.get_val(self.key):
-            rules = [('', _('Select'))] + trans (RULES)
+            rules = [('', _('Select'))] + trans_options(RULES)
         else:
-            rules = trans (RULES[:])
+            rules = trans_options(RULES[:])
 
         table = CTK.PropsTable()
         modul = CTK.PluginSelector (self.key, rules, vsrv_num=vsrv_num)
