@@ -23,6 +23,7 @@
 #
 
 import CTK
+import validations
 
 from util import *
 from consts import *
@@ -34,6 +35,10 @@ REDIRECTION_TYPE = [
     ('1', N_('External'))
 ]
 
+VALIDATIONS = [
+    ('new_redir', validations.is_path)
+]
+
 NOTE_ERROR = N_('HTTP Error to match.')
 NOTE_REDIR = N_('Target to access whenever the HTTP Error occurs.')
 NOTE_TYPE  = N_('Whether the redirection should be Internal or External.')
@@ -79,7 +84,7 @@ class Content (CTK.Container):
 
             for i in entries:
                 show  = CTK.ComboCfg ('%s!%s!show'%(key,i), trans_options(REDIRECTION_TYPE))
-                redir = CTK.RawHTML (CTK.cfg.get_val('%s!%s!url'%(key,i)))
+                redir = CTK.TextCfg  ('%s!%s!url'%(key,i), False)
                 rm    = CTK.ImageStock('del')
                 table += [CTK.RawHTML(i), redir, show, rm]
 
@@ -99,12 +104,14 @@ class Content (CTK.Container):
         table.Add (_('Redirection'), CTK.TextCfg ('new_redir', False, {'class':'noauto'}), _(NOTE_REDIR))
         table.Add (_('Type'),        CTK.ComboCfg('new_type', trans_options(REDIRECTION_TYPE), {'class':'noauto'}), _(NOTE_TYPE))
 
-        dialog = CTK.Dialog({'title': _('Add New Custom Error'), 'width': 540})
-
         submit = CTK.Submitter(url_apply)
+
+        dialog = CTK.Dialog({'title': _('Add New Custom Error'), 'width': 540})
+        dialog.AddButton (_("Close"), 'close')
+        dialog.AddButton (_("Add"),   submit.JS_to_submit())
+
         submit += table
         submit += CTK.HiddenField ({'name': 'key', 'value': key})
-        submit += CTK.SubmitterButton(_('Add'))
         submit.bind ('submit_success', refreshable.JS_to_refresh())
         submit.bind ('submit_success', dialog.JS_to_close())
 
@@ -128,4 +135,4 @@ class Plugin_error_redir (CTK.Plugin):
         self += CTK.Indenter (refresh)
 
         # Validation, and Public URLs
-        CTK.publish ('^%s/[\d]+$'%(URL_APPLY), commit, method="POST")
+        CTK.publish ('^%s/[\d]+$'%(URL_APPLY), commit, method="POST", validation=VALIDATIONS)
