@@ -266,7 +266,7 @@ def version_cmp (x, y):
 # Paths
 #
 
-def path_find_binary (executable, extra_dirs=[], custom_test=None):
+def path_find_binary (executable, extra_dirs=[], custom_test=None, default=None):
     """Find an executable.
     It checks 'extra_dirs' and the PATH.
     The 'executable' parameter can be either a string or a list.
@@ -300,6 +300,9 @@ def path_find_binary (executable, extra_dirs=[], custom_test=None):
                         continue
                 return fp
 
+    # Not found
+    return default
+
 def path_find_w_default (path_list, default=''):
     """Find a path.
     It checks a list of paths (that can contain wildcards),
