@@ -3,7 +3,7 @@
 # Symfony Wizard
 #
 # Authors:
-#      Taher Shihadeh <taher@unixwars.com>
+#      Taher Shihadeh <taher@octality.com>
 #
 # Copyright (C) 2010 Alvaro Lopez Ortega
 #
@@ -57,12 +57,17 @@ PREFIX          = 'tmp!wizard!symfony'
 URL_APPLY       = r'/wizard/vserver/symfony/apply'
 
 CONFIG_DIR = """
-%(pre_rule_plus1)s!document_root = %(local_src_dir)s/web/sf
-%(pre_rule_plus1)s!encoder!gzip = 1
-%(pre_rule_plus1)s!handler = file
-%(pre_rule_plus1)s!handler!iocache = 1
+%(pre_rule_plus2)s!document_root = %(local_src_dir)s/web/sf
+%(pre_rule_plus2)s!encoder!gzip = 1
+%(pre_rule_plus2)s!handler = file
+%(pre_rule_plus2)s!handler!iocache = 1
+%(pre_rule_plus2)s!match = directory
+%(pre_rule_plus2)s!match!directory = %(web_dir)s/sf
+
+%(pre_rule_plus1)s!document_root = %(document_root)s
 %(pre_rule_plus1)s!match = directory
-%(pre_rule_plus1)s!match!directory = %(web_dir)s/sf
+%(pre_rule_plus1)s!match!directory = %(web_dir)s
+%(pre_rule_plus1)s!match!final = 0
 
 # PHP rule
 
@@ -137,7 +142,11 @@ class Commit:
 
         # PHP
         php = CTK.load_module ('php', 'wizards')
+
         error = php.wizard_php_add (next)
+        if error:
+            return {'ret': 'error', 'errors': {'msg': error}}
+
         php_info = php.get_info (next)
 
         # Symfony
@@ -163,7 +172,11 @@ class Commit:
 
         # PHP
         php = CTK.load_module ('php', 'wizards')
+
         error = php.wizard_php_add (next)
+        if error:
+            return {'ret': 'error', 'errors': {'msg': error}}
+
         php_info = php.get_info (next)
 
         # Symfony
@@ -247,6 +260,12 @@ class LocalSource:
         return cont.Render().toStr()
 
 
+class PHP:
+    def __call__ (self):
+        php = CTK.load_module ('php', 'wizards')
+        return php.External_FindPHP()
+
+
 class Welcome:
     def __call__ (self):
         cont = CTK.Container()
@@ -297,13 +316,15 @@ VALS = [
 
 # VServer
 CTK.publish ('^/wizard/vserver/symfony$',   Welcome)
-CTK.publish ('^/wizard/vserver/symfony/2$', LocalSource)
-CTK.publish ('^/wizard/vserver/symfony/3$', Host)
+CTK.publish ('^/wizard/vserver/symfony/2$', PHP)
+CTK.publish ('^/wizard/vserver/symfony/3$', LocalSource)
+CTK.publish ('^/wizard/vserver/symfony/4$', Host)
 
 # Rule
 CTK.publish ('^/wizard/vserver/(\d+)/symfony$',   Welcome)
-CTK.publish ('^/wizard/vserver/(\d+)/symfony/2$', LocalSource)
-CTK.publish ('^/wizard/vserver/(\d+)/symfony/3$', WebDirectory)
+CTK.publish ('^/wizard/vserver/(\d+)/symfony/2$', PHP)
+CTK.publish ('^/wizard/vserver/(\d+)/symfony/3$', LocalSource)
+CTK.publish ('^/wizard/vserver/(\d+)/symfony/4$', WebDirectory)
 
 # Common
 CTK.publish (r'^%s$'%(URL_APPLY), Commit, method="POST", validation=VALS)
