@@ -31,6 +31,7 @@
 # 2010/12/01: uWSGI Version 0.9.6.5 + 0.9.7-dev / Cherokee SVN: r5847
 
 import os
+import sys
 import socket
 import re
 import CTK
@@ -67,8 +68,7 @@ NOTE_WEBDIR_P1    = N_("The default value is extracted from the configuration fi
 PREFIX    = 'tmp!wizard!uwsgi'
 URL_APPLY = r'/wizard/vserver/uwsgi/apply'
 
-UWSGI_CPUS = os.sysconf('SC_NPROCESSORS_ONLN')
-UWSGI_CMDLINE_AUTOMAGIC = "-M -p %d -z %s -L -l %d" % (UWSGI_CPUS*2, CTK.cfg.get_val('server!timeout'), socket.SOMAXCONN)
+UWSGI_CMDLINE_AUTOMAGIC = "-M -p %(CPU_num)d -z %(timeout)s -L -l %(SOMAXCONN)d %(filename)s"
 UWSGI_DEFAULT_CONFS = ('.xml', '.ini', '.yml',)
 UWSGI_MAGIC_CONFS = ('.wsgi', '.py', '.psgi', '.pl', '.lua', '.ws', '.ru', '.rb',)
 
@@ -94,7 +94,6 @@ SINGLE_DIRECTORY = """
 
 """
 
-
 CONFIG_VSERVER = SOURCE + """
 %(vsrv_pre)s!nick = %(new_host)s
 %(vsrv_pre)s!document_root = %(document_root)s
@@ -130,6 +129,18 @@ DEFAULT_PATHS = ['/usr/bin',
                  '/opt/local/sbin',
                  '/opt/local/bin']
 
+
+def figure_CPU_num():
+    if 'SC_NPROCESSORS_ONLN'in os.sysconf_names:
+        return os.sysconf('SC_NPROCESSORS_ONLN')
+
+    proc = subprocess.Popen("sysctl -n hw.ncpu", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    stdout_results, stderr_results = proc.communicate()
+    if len(stderr_results) == 0:
+        return int(stdout_results)
+
+    return 1
+
 class Commit:
     def Commit_VServer (self):
         # Incoming info
@@ -142,7 +153,6 @@ class Commit:
         CTK.cfg['%s!nick'%(vsrv_pre)] = new_host
         Wizard.CloneLogsCfg_Apply ('%s!logs_as_vsrv'%(PREFIX), vsrv_pre)
 
-
         uwsgi_binary = find_uwsgi_binary()
         if not uwsgi_binary:
             uwsgi_binary = CTK.cfg.get_val('%s!uwsgi_binary' %(PREFIX))
@@ -158,11 +168,11 @@ class Commit:
 	    uwsgi_extra = "-s %s %s" % (src_addr, uwsgi_extra)
 	else:
 	    if src_addr.startswith(':'):
-		src_addr = "127.0.0.1%s" % src_addr	
+		src_addr = "127.0.0.1%s" % src_addr
 
         # Build the config
         cvs = CONFIG_VSERVER
-        webdirs = uwsgi_find_mountpoint(uwsgi_cfg)
+        webdirs = uwsgi_find_mountpoint (uwsgi_cfg)
         rule_id = 2
         for webdir in webdirs:
             cvs += SINGLE_DIRECTORY %(locals())
@@ -170,7 +180,6 @@ class Commit:
 
 	cvs += DEFAULT_DIRECTORY
 
-
         # Add the new rules
         config = cvs %(locals())
 
@@ -336,8 +345,12 @@ def uwsgi_get_extra(filename):
     elif filename.endswith('.yml'):
 	return "--yaml %s" % filename
 
-    return "%s %s" % (UWSGI_CMDLINE_AUTOMAGIC, filename)
-	
+    CPU_num   = figure_CPU_num() * 2
+    timeout   = CTK.cfg.get_val('server!timeout', '15')
+    SOMAXCONN = socket.SOMAXCONN
+
+    return UWSGI_CMDLINE_AUTOMAGIC %(locals())
+
 
 def uwsgi_get_modifier(filename):
     if filename.endswith('.psgi') or filename.endswith('.pl'):
@@ -374,28 +387,30 @@ def uwsgi_get_socket(filename):
 	    fd.close()
 	except:
 	    pass
-    
+
     return s
 
-def uwsgi_find_mountpoint(filename):
-    mp = []
+def uwsgi_find_mountpoint (filename):
+    mp       = []
     found_mp = False
-    if filename.endswith('.xml'):
 
+    if filename.endswith('.xml'):
 	try:
             udom = minidom.parse(filename)
             uroot = udom.getElementsByTagName('uwsgi')[0]
 	    for m in uroot.getElementsByTagName('app'):
                 try:
-                    mp.append(m.attributes['mountpoint'].value)
+                    path = CTK.util.to_utf8 (m.attributes['mountpoint'].value)
+                    mp.append (path)
                     found_mp = True
                 except:
-                    pass 
+                    pass
         except:
             pass
-	    
+
     if found_mp:
         return mp
+
     return ['/']
 
 def find_uwsgi_binary():
