@@ -53,12 +53,12 @@ PREFIX          = 'tmp!wizard!zend'
 URL_APPLY       = r'/wizard/vserver/zend/apply'
 
 CONFIG_DIR = """
-# PHP rule
+%(pre_rule_plus1)s!document_root = %(local_src_dir)s
+%(pre_rule_plus)s!match = directory
+%(pre_rule_plus1)s!match!directory = %(web_dir)s
+%(pre_rule_plus11)s!match!final = 0
 
-%(pre_rule_minus1)s!document_root = %(local_src_dir)s
-%(pre_rule_minus1)s!match = directory
-%(pre_rule_minus1)s!match!directory = %(web_dir)s
-%(pre_rule_minus1)s!match!final = 0
+# PHP rule
 
 %(pre_rule_minus2)s!match = and
 %(pre_rule_minus2)s!match!final = 1
