@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -62,7 +62,7 @@ ret_t cherokee_avl_get_ptr   (cherokee_avl_t *avl, const char *key, void **value
 ret_t cherokee_avl_len       (cherokee_avl_t *avl, size_t *len);
 ret_t cherokee_avl_while     (cherokee_avl_t *avl, cherokee_avl_while_func_t func, void *param, cherokee_buffer_t **key, void **value);
 
-ret_t cherokee_avl_set_case  (cherokee_avl_t *avl, cherokee_boolean_t case_sensitive);
+ret_t cherokee_avl_set_case  (cherokee_avl_t *avl, cherokee_boolean_t case_insensitive);
 ret_t cherokee_avl_check     (cherokee_avl_t *avl);
 ret_t cherokee_avl_print     (cherokee_avl_t *avl);
 
