@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -38,6 +38,7 @@
 #include "http.h"
 #include "validator.h"
 #include "nullable.h"
+#include "encoder.h"
 
 #define CHEROKEE_CONFIG_PRIORITY_NONE    0
 #define CHEROKEE_CONFIG_PRIORITY_DEFAULT 1
@@ -67,18 +68,6 @@ typedef enum {
 } cherokee_expiration_props_t;
 
 
-typedef enum {
-	cherokee_encoder_unset,
-	cherokee_encoder_allow,
-	cherokee_encoder_forbid
-} cherokee_encoder_perms_t;
-
-typedef struct {
-	cherokee_encoder_perms_t  perms;
-	void                     *instance_func;
-} cherokee_encoder_avl_entry_t;
-
-
 typedef struct {
 	/* Properties
 	 */
@@ -131,11 +120,16 @@ ret_t cherokee_config_entry_free     (cherokee_config_entry_t  *entry);
 ret_t cherokee_config_entry_init     (cherokee_config_entry_t  *entry);
 ret_t cherokee_config_entry_mrproper (cherokee_config_entry_t  *entry);
 
-ret_t cherokee_config_entry_encoder_add    (cherokee_config_entry_t *entry, cherokee_buffer_t *name, cherokee_plugin_info_t *plugin_info);
-ret_t cherokee_config_entry_encoder_forbid (cherokee_config_entry_t *entry, cherokee_buffer_t *name);
+ret_t cherokee_config_entry_set_encoder (cherokee_config_entry_t  *entry,
+					 cherokee_buffer_t        *encoder_name,
+					 cherokee_plugin_info_t   *plugin_info,
+					 cherokee_encoder_props_t *encoder_props);
 
-ret_t cherokee_config_entry_set_handler (cherokee_config_entry_t *entry, cherokee_plugin_info_handler_t *plugin_info);
-ret_t cherokee_config_entry_complete    (cherokee_config_entry_t *entry, cherokee_config_entry_t *source);
+ret_t cherokee_config_entry_set_handler (cherokee_config_entry_t        *entry,
+					 cherokee_plugin_info_handler_t *plugin_info);
+
+ret_t cherokee_config_entry_complete    (cherokee_config_entry_t *entry,
+					 cherokee_config_entry_t *source);
 
 ret_t cherokee_config_entry_print       (cherokee_config_entry_t *entry);
 
