@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -50,7 +50,7 @@ typedef ret_t (* cryptor_vsrv_func_free_t)      (void  *cryp);
 /* Cryptor: Socket */
 typedef ret_t (* cryptor_socket_func_free_t)    (void *cryp);
 typedef ret_t (* cryptor_socket_func_clean_t)   (void *cryp);
-typedef ret_t (* cryptor_socket_func_init_tls_t)(void *cryp, void *sock, void *vsrv, void *blocking);
+typedef ret_t (* cryptor_socket_func_init_tls_t)(void *cryp, void *sock, void *vsrv, void *conn, void *blocking);
 typedef ret_t (* cryptor_socket_func_shutdown_t)(void *cryp);
 typedef ret_t (* cryptor_socket_func_read_t)    (void *cryp, char *buf, int len, size_t *re_len);
 typedef ret_t (* cryptor_socket_func_write_t)   (void *cryp, char *buf, int len, size_t *re_len);
@@ -64,6 +64,7 @@ typedef ret_t (* cryptor_client_func_init_t)    (void  *cryp, void *host, void *
 typedef struct {
 	cherokee_module_t          module;
 	cint_t                     timeout_handshake;
+	cherokee_boolean_t         allow_SSLv2;
 
 	/* Methods */
 	cryptor_func_configure_t   configure;
@@ -158,6 +159,7 @@ ret_t cherokee_cryptor_socket_shutdown    (cherokee_cryptor_socket_t *cryp);
 ret_t cherokee_cryptor_socket_init_tls    (cherokee_cryptor_socket_t *cryp,
 					   void                      *sock,
 					   void                      *vsrv,
+					   void                      *conn,
 					   void                      *blocking);
 ret_t cherokee_cryptor_socket_read        (cherokee_cryptor_socket_t *cryp,
 					   char                      *buf,
