@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -124,22 +124,26 @@ typedef struct {
 
 /* Handler methods
  */
-ret_t cherokee_handler_init_base   (cherokee_handler_t  *hdl, void *conn, cherokee_handler_props_t *props, cherokee_plugin_info_handler_t *info);
-ret_t cherokee_handler_free_base   (cherokee_handler_t  *hdl);
+ret_t cherokee_handler_init_base   (cherokee_handler_t *hdl, void *conn, cherokee_handler_props_t *props, cherokee_plugin_info_handler_t *info);
+ret_t cherokee_handler_free_base   (cherokee_handler_t *hdl);
 
 /* Handler virtual methods
  */
-ret_t cherokee_handler_init        (cherokee_handler_t  *hdl);
-ret_t cherokee_handler_free        (cherokee_handler_t  *hdl);
-ret_t cherokee_handler_read_post   (cherokee_handler_t  *hdl);
-ret_t cherokee_handler_add_headers (cherokee_handler_t  *hdl, cherokee_buffer_t *buffer);
-ret_t cherokee_handler_step        (cherokee_handler_t  *hdl, cherokee_buffer_t *buffer);
+ret_t cherokee_handler_init        (cherokee_handler_t *hdl);
+ret_t cherokee_handler_free        (cherokee_handler_t *hdl);
+ret_t cherokee_handler_read_post   (cherokee_handler_t *hdl);
+ret_t cherokee_handler_add_headers (cherokee_handler_t *hdl, cherokee_buffer_t *buffer);
+ret_t cherokee_handler_step        (cherokee_handler_t *hdl, cherokee_buffer_t *buffer);
 
 /* Handler properties methods
  */
 ret_t cherokee_handler_props_init_base  (cherokee_handler_props_t *props, module_func_props_free_t free_func);
 ret_t cherokee_handler_props_free_base  (cherokee_handler_props_t *props);
 
+/* Utilities
+ */
+ret_t cherokee_handler_add_header_options (cherokee_handler_t *hdl, cherokee_buffer_t *buffer);
+
 CHEROKEE_END_DECLS
 
 #endif /* CHEROKEE_HANDLER_H */
