@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -82,6 +82,10 @@ typedef enum {
 	http_invalid          = 1LL << 32
 } cherokee_http_method_t;
 
+#define cherokee_http_method_LENGTH 33
+#define HTTP_METHOD(x) ((cherokee_http_method_t)(x))
+
+
 typedef enum {
 	http_auth_nothing = 0,
 	http_auth_basic   = 1,
@@ -225,12 +229,14 @@ typedef enum {                               /* Protocol   RFC  Section */
 				   (m == http_merge)     || \
 				   (m == http_search)    || \
 				   (m == http_report)    || \
-				   (m == http_options)   || \
 				   (m == http_checkout)  || \
 				   (m == http_propfind)  || \
 				   (m == http_proppatch) || \
 				   (m == http_mkactivity))
 
+#define http_method_with_optional_input(m) (m == http_options)
+
+
 /* RFC 2616: Section 4.3 */
 #define http_code_with_body(e)    ((! http_type_100(e))            /* 1xx */ && \
 				   ((e) != http_no_content)        /* 204 */ && \
